@@ -3,26 +3,13 @@
 """
 a tool for exploring DSP concepts
 
-David Banas <dbanas@banasfamily.net>
+David Banas <capn.freako@gmail.com>
 11 June 2011
 
 This Python script provides a means for exploring DSP concepts, using the
 GUI and modeling tools available in the Enthought Tool Suite.
 
-$Id: pydsp.py 36 2012-01-19 13:36:51Z dbanas $
-
 Copyright (c) 2011 by David Banas; All rights reserved World wide.
-
-Revision History:
- Date      SVN # Description
- ____________________________________________________________________________
- 2011-06-11   13 Initial revision (copied from 'PhYsics/damped_spring.py').
- 2011-06-13   15 Release of v0.1
- 2011-07-09   34 Release of v0.2
-
-To Do:
- - Show single point FFT as matched filter.
-
 """
 
 from enthought.traits.api \
@@ -83,9 +70,9 @@ class PyDSP (HasTraits):
     y = Property(Array, depends_on=['a', 'x'])
     plot_type = Enum("line", "scatter")
     plot_type2 = Enum("line", "scatter")
-    ident = String('PyDSP v0.2 - a digital filter design tool, written in Python\n\n \
-    David Banas\n \
-    July 9, 2011\n\n \
+    ident = String('PyDSP v0.4 - a digital filter design tool, written in Python\n\n \
+    David Banas <capn.freako@gmail.com>\n \
+    October 15, 2014\n\n \
     Copyright (c) 2011 David Banas; All rights reserved World wide.')
 
     # Set the default values of the independent variables.
@@ -349,12 +336,10 @@ view1 = View(
   ),
   resizable = True,
   handler = MyHandler(),
-#  buttons = ["CopyCoefficients", "OK"],
   buttons = [copy_coeffs, "OK"],
   title='DSP Filter Tool',
-  width=1200, height=900
+  width=1200, height=800
 )
 
 if __name__ == '__main__':
-    viewer = PyDSP()
-    viewer.configure_traits(view=view1)
+    PyDSP().configure_traits(view=view1)
